@@ -1,7 +1,7 @@
 from functools import wraps
 from pydantic import BaseModel
 import inspect
-from magicapi import settings
+from magicapi import g
 
 from magicapi.Decorators.helpers import async_safe
 
@@ -27,7 +27,7 @@ def parse_objects(f):
             ):
                 kwargs[var_name] = this_class.parse_obj(var_val)
 
-        if settings.print_level > 1:
+        if g.settings.print_level > 1:
             print("PARSE OBJS", "args", args, "kwargs", kwargs)
 
         return await async_safe(f, *args, **kwargs)
